@@ -48,7 +48,6 @@ impl_bonobo_control_frame_get_parent_accessible (PortableServer_Servant servant,
 {
   BonoboControlFrame *control_frame = BONOBO_CONTROL_FRAME (bonobo_object_from_servant (servant));
   AtkObject          *atko;
-  AtkObject          *parent;
 
   dprintf ("Bonobo::ControlFame::getParentAccessible [%p]\n", control_frame);
 
@@ -57,10 +56,8 @@ impl_bonobo_control_frame_get_parent_accessible (PortableServer_Servant servant,
   atko = gtk_widget_get_accessible (
 	  bonobo_control_frame_get_widget (control_frame));
 
-  parent = atk_object_get_parent (atko);  
-
   return CORBA_Object_duplicate (
-	  BONOBO_OBJREF (spi_accessible_new (parent)), ev);
+	  BONOBO_OBJREF (spi_accessible_new (atko)), ev);
 }
 
 static Bonobo_Unknown
